# Python 3 code to generate the figure displaying compressive and tensile strength of cometary material in Biele et al (2022)
# Jean-Baptiste Vincent

# To generate the figure, typ "python fig_strength_biele2022.py" on the command line

# Required dependency: MATPLOTLIB
import matplotlib.pyplot as plt
import matplotlib.patches as patches
import matplotlib.lines as mlines


# DATA, EXTRACTED FROM PUBLICATIONS
# [publication, scaleMin (m), scaleMax (m), Ymin (Pa), Ymax (Pa)]
tensileY = [
    ["Biele+2009", 1e3, 10e3, 3, 100],
    ["Thomas+2015", 7, 14, 10, 20],
    ["Grousssin+2015", 5, 30, 3, 15],
    ["Vincent+2015,2017", 10, 200, 2, 50],
    ["Basilevsky+2016", 5, 200, 1.5, 100],
    ["Attree+2017", 10, 100, 1, 30],
    ["Matonti+2019", 100, 1000, 100, 450]
]

# [publication, scaleMin (m), scaleMax (m), Ymin (Pa), Ymax (Pa)]
compressiveY = [
    ["Biele+2015", .1, 1, 1000, 3000],
    ["Spohn+2015", 5e-3, 10e-3, 2e6, 4e6],
    ["Grousssin+2015", 10, 1000, 30, 150],
    ["Basilevsky+2016", 10, 1000, 30, 1000],
    ["Möhlmann+2018", .1, 1, 8000, 12000],
    ["Roll+2016", .1, 1, 1550, 1800],
    ["Heinisch+2019", .3, 1.8, 7, 399],
    ["Vincent+2019", 5, 10, 200, 2000],
    ["O\'Rourke+2020", .2, 1.5, 1, 12],
    ["this study", 5e-2, 30e-2, 28e3, 690e3]
]

# reference grid lines showing the expected 1/sqrt(scale) dependency
refS      = [1e-3, 1e-2, 0.1, 1, 10, 1e2, 1e3, 1e4] # scale in m
K = 30 # arbitrary factor to center the grid lines in the display
refY_100   = [0.1*K*d**-.5 for d in refS]
refY_1k    = [    K*d**-.5 for d in refS]
refY_10k   = [ 10*K*d**-.5 for d in refS]
refY_100k  = [100*K*d**-.5 for d in refS]
refY_1000k = [1000*K*d**-.5 for d in refS]
refY_10000k= [10000*K*d**-.5 for d in refS]

# Print list of references, for the figure caption
alph = "abcdefghijklmnopqrstuvwxyz"
ref_list = ""
ref_id=0
for ref in tensileY:
    ref_list += "({}) {}, ".format(alph[ref_id], tensileY[ref_id][0])
    ref_id += 1

offset = len(tensileY)
for ref in compressiveY:
    ref_list += "({}) {}, ".format(alph[ref_id], compressiveY[ref_id-offset][0])
    ref_id += 1

print(ref_list)


# DISPLAY FIGURE AND EXPORT TO PNG AND EPS
fs = 16 #general font size

fig, ax = plt.subplots(1, 1, figsize=(16,12))
ax.loglog(refS, refY_100, color=[.8,.8,.8])
ax.loglog(refS, refY_1k, color=[.8,.8,.8])
ax.loglog(refS, refY_10k, color=[.8,.8,.8])
ax.loglog(refS, refY_100k, color=[.8,.8,.8])
ax.loglog(refS, refY_1000k, color=[.8,.8,.8])
ax.loglog(refS, refY_10000k, color=[.8,.8,.8])

plot_id = 0
for P in tensileY:
    rect = patches.Rectangle((P[1],P[3]), P[2]-P[1], P[4]-P[3], linewidth=2, linestyle='dashed', edgecolor='b', facecolor='none', zorder=2)
    ax.add_patch(rect)
    ax.text(P[1]*1.05, P[4]*0.7, alph[plot_id], color="blue", style='italic', fontsize=fs)
    plot_id += 1

for P in compressiveY:
    rect = patches.Rectangle((P[1],P[3]), P[2]-P[1], P[4]-P[3], linewidth=2, edgecolor='r',facecolor='none', zorder=2)
    ax.add_patch(rect)
    ax.text(P[1]*1.05, P[4]*0.7, alph[plot_id], color="red", fontsize=fs)
    plot_id += 1

ax.set_ylim([.5, 1e7])
ax.set_xlim([.4e-2, 12e3])
ax.set_xlabel("Scale (m)", fontsize=fs)
ax.set_ylabel("Strength (Pa)", fontsize=fs)

gray_line = mlines.Line2D([], [], color=[.8,.8,.8], label=r'$strength \propto scale^{-1/2}$')
blue_line = mlines.Line2D([], [], color='blue', label='tensile strength', linestyle='dashed')
red_line  = mlines.Line2D([], [], color='red', label='compressive strength')
ax.add_line(gray_line)
ax.add_line(blue_line)
ax.add_line(red_line)
ax.legend(fontsize=fs)

plt.xticks(fontsize=fs)
plt.yticks(fontsize=fs)

plt.show()

fig.savefig("fig_strength_biele2022.png", dpi=150, bbox_inches='tight', facecolor='white')
fig.savefig("fig_strength_biele2022.eps", dpi=150, bbox_inches='tight', facecolor='white')
